<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name></name>
    <message>
        <source>Delete</source>
        <translation type="vanished">删除</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">全屏</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">幻灯片放映</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">导出</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">复制</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">收藏</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">顺时针旋转</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">逆时针旋转</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">设为壁纸</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">在文件管理器中显示</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">照片信息</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="vanished">视频信息</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">恢复</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>未命名相册</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>新建相册</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>您确定要删除此相册吗？</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>最近删除</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>已导入</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>最近删除</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>我的收藏</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>您也可以拖拽照片到此</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>全部导入</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>导入到：</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>导入</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>系统盘</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>照片库</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>磁盘文件被占用，无法弹出</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相册</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>正在加载，请稍候...</translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation>文件在删除前会显示剩余天数，之后将永久删除</translation>
    </message>
    <message>
        <source>Image classification</source>
        <translation>照片分类</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>相册</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>替换</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文档</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>文件名：</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>保存到：</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>文件格式：</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>照片质量：</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>选择其他目录</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>文件名不能为空</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>已存在，您是否要替换？</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation>截图录屏</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>相机</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>画板</translation>
    </message>
    <message>
        <source>(copy)</source>
        <translation>(副本)</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1驱动器</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>空白%1光盘</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>%1已加密</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1卷</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>导出照片</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>正在删除...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>正在恢复...</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation>正在分类，请稍后...</translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation>您确定要永久删除此文件吗？</translation>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation>删除后不可恢复</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation>您确定要永久删除这%1个文件吗？</translation>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation>删除后不可恢复</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation>您确定要从本地删除此文件吗？</translation>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation>您可以在“最近删除”中进行恢复</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation>您确定要从本地删除这%1个文件吗？</translation>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation>您可以在“最近删除”中进行恢复</translation>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>基本信息</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>详细信息</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>图片信息</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>已导入</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>共1张照片</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>共1个视频</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>共%n张照片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>共%n个视频</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>共%n项</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>导入照片和视频</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>您也可以拖拽照片和视频到此</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>所有照片和视频</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>未发现照片或视频文件</translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>设备</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>照片库</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>相册</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相册</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>相册是一款可多种方式浏览、整理照片和视频的管理工具。</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>照片</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>设为壁纸</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一张</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一张</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>重命名相册</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>已成功删除“%1”相册</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>成功添加到“%1”</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>导入成功</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>导入失败</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>导出失败</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>导出成功</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>所有照片</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>时间线</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>相册</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>退出全屏/幻灯片放映</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>全选</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>放大照片</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>缩小照片</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相册</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>向上滚动一屏</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>向下滚动一屏</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>正在导入，请稍候...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>所有照片和视频</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>导入照片和视频</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>未发现照片或视频文件</translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation>导出照片</translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation>导入照片和视频</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation>照片/视频信息</translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation>导入照片和视频</translation>
    </message>
    <message>
        <source>Import folders</source>
        <translation>从文件夹导入</translation>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation>导入中断</translation>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation>不支持此路径，请尝试其他路径</translation>
    </message>
    <message>
        <source>The path already exists</source>
        <translation>路径已存在</translation>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation>%1个文件恢复失败，文件名过长</translation>
    </message>
    <message>
        <source>Classifying...</source>
        <translation>正在分类，请稍后...</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>闪光灯</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>文件类型</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>照片尺寸</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>拍摄日期</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>曝光程序</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>曝光时间</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>光圈大小</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>焦距</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO感光度</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>最大光圈值</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>测光模式</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>白平衡</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>闪光灯补偿</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>相机型号</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>镜头型号</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>颜色空间</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>标记</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>无结果</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>系统盘</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>选择</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>取消选择</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1年%2月%3日</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>导入于</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1年%2月%3日 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>导入于</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>取消全选</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>恢复</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>All</source>
        <translation>所有项目</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>照片</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>无结果</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>正在导入，请稍候…</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>已导入%1/%2项</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>已删除%1/%2项</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>%1个项目导入成功，%2个项目导入失败</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>已选择1张照片</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>已选择1个视频</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>照片/视频已存在</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation>
            <numerusform>已选择%n张照片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation>
            <numerusform>已选择%n个视频</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation>
            <numerusform>已选择%n项</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>%1个项目导入成功，%2个项目已存在</translation>
    </message>
    <message>
        <source>Plants</source>
        <translation>植物</translation>
    </message>
    <message>
        <source>Scenery</source>
        <translation>风景</translation>
    </message>
    <message>
        <source>Food</source>
        <translation>美食</translation>
    </message>
    <message>
        <source>Scene</source>
        <translation>场景</translation>
    </message>
    <message>
        <source>Items</source>
        <translation>物体</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其它</translation>
    </message>
    <message>
        <source>%1/%2 items classifyed</source>
        <translation>已分类%1/%2项</translation>
    </message>
    <message>
        <source>Humans</source>
        <translation>人物</translation>
    </message>
    <message>
        <source>Animals</source>
        <translation>动物</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>搜索结果</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>共找到1张照片</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation>
            <numerusform>共找到%n个视频</numerusform>
        </translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>共找到1个视频</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation>
            <numerusform>共找到%n项</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation>
            <numerusform>共找到%n张照片</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1张照片</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1个视频</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>%n张照片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>%n个视频</numerusform>
        </translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation>正在导入：%1</translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation>正在导出：%1</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>设为壁纸</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻灯片放映</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>照片信息</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>添加到相册</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>从相册中移除</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>恢复</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相册</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>视频信息</translation>
    </message>
    <message>
        <source>days</source>
        <translation>天</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>共1张照片</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>共1个视频</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation>
            <numerusform>共%n张照片</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation>
            <numerusform>共%n个视频</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation>
            <numerusform>共%n项</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>基本信息</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>编码信息</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>音频流信息</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>视频流信息</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>视频码率</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>视频帧率</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>显示比例</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>分辨率</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>编码样式</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>编码码率</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation>音频位数</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>声道数</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>声道</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>采样数</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>文件类型</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>时长</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>文件路径</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>视频信息</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>拍摄日期</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名称</translation>
    </message>
</context>
</TS>
